==> magic-7.2.24.tgz: magic-7.2.24/irouter/irouter.h <==
/*
 * irouter.h --
 *
 * This file defines the interface provided by the interactive router
 * module, which is the top-level module that controls interactive
 * routing.
 *
 *     ********************************************************************* 
 *     * Copyright (C) 1987, 1990 Michael H. Arnold, Walter S. Scott, and  *
 *     * the Regents of the University of California.                      *
 *     * Permission to use, copy, modify, and distribute this              * 
 *     * software and its documentation for any purpose and without        * 
 *     * fee is hereby granted, provided that the above copyright          * 
 *     * notice appear in all copies.  The University of California        * 
 *     * makes no representations about the suitability of this            * 
 *     * software for any purpose.  It is provided "as is" without         * 
 *     * express or implied warranty.  Export of this software outside     * 
 *     * of the United States of America may require an export license.    * 
 *     *********************************************************************
 *
 * rcsid $Header: /ufs/repository/magic/irouter/irouter.h,v 1.1.1.1 2000/03/29 18:35:07 rajit Exp $
 */

#define _IROUTER

/*
 * Interface procedures.
 */

extern Void IRInit();
extern Void IRTest();
extern Void IRButtonProc();

/*
 * Technology file client procedures.
 * The sections should be processed in the order
 * listed below.
 */

    /* "irouter" section */
extern Void IRTechInit();
extern bool IRTechLine();

    /* "drc" section */
extern Void IRDRCInit();
extern bool IRDRCLine();

==> magic-7.4.35.tgz: magic-7.4.35/irouter/irouter.h <==
/*
 * irouter.h --
 *
 * This file defines the interface provided by the interactive router
 * module, which is the top-level module that controls interactive
 * routing.
 *
 *     ********************************************************************* 
 *     * Copyright (C) 1987, 1990 Michael H. Arnold, Walter S. Scott, and  *
 *     * the Regents of the University of California.                      *
 *     * Permission to use, copy, modify, and distribute this              * 
 *     * software and its documentation for any purpose and without        * 
 *     * fee is hereby granted, provided that the above copyright          * 
 *     * notice appear in all copies.  The University of California        * 
 *     * makes no representations about the suitability of this            * 
 *     * software for any purpose.  It is provided "as is" without         * 
 *     * express or implied warranty.  Export of this software outside     * 
 *     * of the United States of America may require an export license.    * 
 *     *********************************************************************
 *
 * rcsid $Header: /usr/cvsroot/magic-7.4/irouter/irouter.h,v 1.1.1.1 2006/04/10 22:02:12 tim Exp $
 */

#ifndef _IROUTER_H
#define _IROUTER_H

#include "utils/magic.h"

/*
 * Interface procedures.
 */

extern void IRInit();
extern void IRTest();
extern void IRButtonProc();

/*
 * Technology file client procedures.
 * The sections should be processed in the order
 * listed below.
 */

    /* "irouter" section */
extern void IRTechInit();
extern bool IRTechLine();

    /* "drc" section */
extern void IRDRCInit();
extern bool IRDRCLine();

#endif /* _IROUTER_H */
